import { QspAPI, QspVariableType } from '../contracts/api';
import { QspPanel } from '../contracts/common';
import { QspEvents } from '../contracts/events';
import { Ptr, QspWasmModule, StringPtr } from '../contracts/wasm-module';
export declare class QspAPIImpl implements QspAPI {
    private module;
    private listeners;
    private variableWatchers;
    private variableValues;
    private time;
    private staticStrings;
    constructor(module: QspWasmModule);
    on<E extends keyof QspEvents>(event: E, listener: QspEvents[E]): void;
    off<E extends keyof QspEvents>(event: E, listener: QspEvents[E]): void;
    watchVariable<Name extends string>(name: Name, callback: (value: QspVariableType<Name>) => void): () => void;
    watchVariableByIndex<Name extends string>(name: Name, index: number, callback: (value: QspVariableType<Name>) => void): () => void;
    watchVariableByKey<Name extends string>(name: Name, key: string, callback: (value: QspVariableType<Name>) => void): () => void;
    private emit;
    openGame(data: ArrayBuffer, isNewGame: boolean): void;
    saveGame(): ArrayBuffer | null;
    loadSave(data: ArrayBuffer): void;
    restartGame(): void;
    selectAction(index: number): void;
    execSelectedAction(): void;
    selectObject(index: number): void;
    version(): string;
    getStaticStringPointer(name: string): Ptr;
    readVariable<Name extends string>(name: Name, useCache?: boolean): QspVariableType<Name>;
    readVariableByIndex<Name extends string>(name: Name, index: number, useCache?: boolean): QspVariableType<Name>;
    readVariableByKey<Name extends string>(name: Name, key: string, useCache?: boolean): QspVariableType<Name>;
    readVariableSize(name: string): number;
    execCode(code: string, isRefresh?: boolean): void;
    execCounter(): void;
    execLoc(name: string): void;
    updateUserInput(code: string): void;
    enableDebugMode(): void;
    disableDebugMode(): void;
    getLocationsList(): string[];
    getLocationCode(name: string): string[];
    getActionCode(location: string, index: number): string[];
    private init;
    private registerCallbacks;
    private registerCallback;
    onError: () => void;
    onRefresh: (isRedraw: boolean) => void;
    onShowWindow: (type: QspPanel, isShown: boolean) => void;
    onMenu: (listPtr: Ptr, count: number) => void;
    onMsg: (textPtr: StringPtr) => void;
    onInput: (textPtr: StringPtr, retPtr: Ptr, maxSize: number) => void;
    onVersion: (textPtr: StringPtr, retPtr: Ptr, maxSize: number) => void;
    onWait: (ms: number) => void;
    onSetTimer: (ms: number) => void;
    onSetUserInput: (textPtr: StringPtr) => void;
    onView: (pathPtr: StringPtr) => void;
    onDebug: (strPtr: StringPtr) => void;
    onSystemCmd: (strPtr: StringPtr) => void;
    onGetMS: () => number;
    onOpenGame: (pathPtr: StringPtr, isNewGame: boolean) => void;
    onOpenGameStatus: (pathPtr: StringPtr) => void;
    onSaveGameStatus: (pathPtr: StringPtr) => void;
    onIsPlay: (filePtr: StringPtr) => void;
    onPlayFile: (filePtr: StringPtr, volume: number) => void;
    onCloseFile: (filePtr: StringPtr) => void;
    clearCache(): void;
    _run_checks(): void;
    _cleanup(): void;
    private reportWatched;
    toJSON(): string;
}
